import type { WGSLCanvasUniform } from "./WGSLCanvasUniform.js";
export declare class WGSLCanvas {
    /**
     * Uniforms object
     */
    readonly uniforms: Record<string, WGSLCanvasUniform>;
    /**
     * Keys for "uniforms" object
     */
    uniformsKeys: string[];
    /**
     * Textures list
     */
    textures: GPUCopyExternalImageSource[];
    /**
     * Default fragment shader
     */
    static SHADER_FRAGMENT_DEFAULT: string;
    private _shaderFragmentNeedsUpdate;
    private _shaderFragment;
    /**
     * Gets current fragment shader WGSL code
     */
    get shaderFragment(): string;
    /**
     * Sets fragment shader WGSL code
     */
    set shaderFragment(value: string);
    private readonly _canvas;
    private readonly _context;
    private readonly _format;
    private _adapter;
    private _device;
    constructor({ canvas }: {
        canvas: HTMLCanvasElement;
    });
    /**
     * Initializes internal canvas GPU context.
     * Must run once after the creation of "WGSLCanvas" instance.
     */
    init(): Promise<void>;
    /**
     * Checks if WebGPU is supported on this browser/device.
     */
    static isSupported(): boolean;
    /**
     * Loads texture from URL, creates bitmap image that can be further drawn on the canvas through shader.
     */
    static loadTexture(url: string): Promise<ImageBitmap>;
    private _shaderModuleVertex;
    private _shaderModuleFragment;
    private _renderPipeline;
    private _sampler;
    /**
     * Renders shader output to the canvas.
     */
    render(): void;
}
